update_engine: Fix TPM variable name max_kernel_rollfoward

- In a previous CL I named the variable incorrectly

BUG=chromium:814090
TEST=FEATURES=test emerge-samus update_engine

Change-Id: I17cbc85d42ba03040bfdae436cedd0238698b47e
Reviewed-on: https://chromium-review.googlesource.com/1059944
Commit-Ready: Zentaro Kavanagh <zentaro@chromium.org>
Tested-by: Zentaro Kavanagh <zentaro@chromium.org>
Reviewed-by: Amin Hassani <ahassani@chromium.org>
diff --git a/common/hardware_interface.h b/common/hardware_interface.h
index 4946b91..4d7c162 100644
--- a/common/hardware_interface.h
+++ b/common/hardware_interface.h
@@ -79,9 +79,9 @@
   virtual int GetMinFirmwareKeyVersion() const = 0;
 
   // Sets the maximum kernel key version that verified boot should roll
   // forward to. This is the value of crossystem max_kernel_rollforward.
   // Returns false if the value cannot be set, or if not running on Chrome OS.
-  virtual bool SetMaxKernelKeyRollforward(int max_kernel_rollforward) = 0;
+  virtual bool SetMaxKernelKeyRollforward(int kernel_max_rollforward) = 0;
 
   // Returns the powerwash_count from the stateful. If the file is not found
   // or is invalid, returns -1. Brand new machines out of the factory or after
@@ -79,9 +79,9 @@
 
   // Sets the maximum kernel key version that verified boot should roll
-  // forward to. This is the value of crossystem max_kernel_rollforward.
+  // forward to. This is the value of crossystem kernel_max_rollforward.
   // Returns false if the value cannot be set, or if not running on Chrome OS.